# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog,
and this project adheres to Semantic Versioning.

---

## [Unreleased]

### Added
- 

### Changed
- 

### Fixed
- 

---

## [0.2.0] - 2026-03-08
### Added
- `nav_history_lazy()` to return results into a `pl.LazyFrame`.
- Python type stubs for the public API.
### Changed
- Migrated all backend logic to Rust.
- Removed rate limiting per second.
### Fixed
- 
---

## [0.1.3] - 2026-02-14

### Added
- 

### Changed
- Made `nav_response_to_df()` faster by removing `.select()` and not creating a `dict` object.

### Fixed
- 

---

## [0.1.2] - 2026-02-14

### Added
- Added `py.typed` marker (PEP 561) to enable static type checking for downstream users.

---

## [0.1.1] - 2026-02-13

### Added
- Initial public release.
- Core functionality.
- Inline type hints.
